Index: /trunk/bibopa.sh
===================================================================
--- /trunk/bibopa.sh	(revision 30)
+++ /trunk/bibopa.sh	(revision 31)
@@ -35,5 +35,5 @@
 # $ ./bibopa.sh -i data/mail2007-04-25T08:58:16Z.txt -t mailbody
 #
-# see also mailtousernemo.sh
+# see also mailtouser.sh
 #
 # original location :
Index: /trunk/compilers_db.xsl
===================================================================
--- /trunk/compilers_db.xsl	(revision 30)
+++ /trunk/compilers_db.xsl	(revision 31)
@@ -21,5 +21,5 @@
 
 <xsl:template name="compilers">
- <xsl:param name="usernemo"/>
+ <xsl:param name="user"/>
  <xsl:param name="visu_modif"/>
 
@@ -37,5 +37,5 @@
    <xsl:element name="label">
    -->
-    <xsl:for-each select="$usernemo/compilers/compiler">
+    <xsl:for-each select="$user/compilers/compiler">
      <xsl:sort order="ascending" data-type="text" select="@code"/>
      <xsl:text>&#xA;</xsl:text>
Index: /trunk/components_db.xsl
===================================================================
--- /trunk/components_db.xsl	(revision 30)
+++ /trunk/components_db.xsl	(revision 31)
@@ -26,5 +26,5 @@
 
 <xsl:template name="components">
- <xsl:param name="usernemo"/>
+ <xsl:param name="user"/>
  <xsl:param name="visu_modif"/>
 
@@ -40,5 +40,5 @@
     <xsl:element name="label">
    -->
-    <xsl:for-each select="$usernemo/components/component">
+    <xsl:for-each select="$user/components/component">
      <xsl:sort order="ascending" data-type="text" select="@code"/>
      <xsl:text>&#xA;</xsl:text>
@@ -88,5 +88,5 @@
      <xsl:attribute name="name">components_date</xsl:attribute>
      <xsl:attribute name="type">text</xsl:attribute>
-     <xsl:attribute name="value"><xsl:value-of select="$usernemo/components/components_date"/></xsl:attribute>
+     <xsl:attribute name="value"><xsl:value-of select="$user/components/components_date"/></xsl:attribute>
     </xsl:element>
    </xsl:element>
Index: /trunk/data/userdemo1.xml
===================================================================
--- /trunk/data/userdemo1.xml	(revision 31)
+++ /trunk/data/userdemo1.xml	(revision 31)
@@ -0,0 +1,112 @@
+<?xml version="1.0" encoding="iso-8859-1"?>
+<!DOCTYPE users SYSTEM "user.dtd">
+<!--
+module :
+base des users demo1
+
+update :
+$Id$
+fplod 2007-11-15T14:08:58Z aedon.locean-ipsl.upmc.fr (Darwin)
+creation
+-->
+<users>
+<date>2007-11-15T14:08:58Z</date>
+<user>
+<userid>template</userid>
+<personname>
+<surname></surname>
+<firstname></firstname>
+<othername role='mi'></othername>
+</personname>
+<email></email>
+<components>
+<components_date>
+</components_date>
+<component code="opa">
+<name>OPA</name>
+<value>no</value>
+</component>
+<component code="lim">
+<name>LIM</name>
+<value>no</value>
+</component>
+<component code="top">
+<name>TOP</name>
+<value>no</value>
+</component>
+<component code="tam">
+<name>TAM</name>
+<value>no</value>
+</component>
+<component code="saxo">
+<name>SAXO</name>
+<value>no</value>
+</component>
+</components>
+<platforms>
+<platform code="cray">
+<name>CRAY</name>
+<value>no</value>
+</platform>
+<platform code="ibm">
+<name>IBM</name>
+<value>no</value>
+</platform>
+<platform code="fujitsu">
+<name>FUJITSU</name>
+<value>no</value>
+</platform>
+<platform code="mac">
+<name>MAC</name>
+<value>no</value>
+</platform>
+<platform code="nec">
+<name>NEC</name>
+<value>no</value>
+</platform>
+<platform code="sgi">
+<name>SGI</name>
+<value>no</value>
+</platform>
+<platform code="sun">
+<name>SUN</name>
+<value>no</value>
+</platform>
+<platform code="pccluster">
+<name>PC Cluster</name>
+<value>no</value>
+</platform>
+<platform code="zzz_other">
+<name>Other</name>
+<value></value>
+</platform>
+</platforms>
+<processors></processors>
+<compilers>
+<compiler code="g95">
+<name>g95</name>
+<value>no</value>
+</compiler>
+<compiler code="ifort">
+<name>ifort</name>
+<value>no</value>
+</compiler>
+<compiler code="pgf">
+<name>pgf</name>
+<value>no</value>
+</compiler>
+<compiler code="sxf90">
+<name>sxf90</name>
+<value>no</value>
+</compiler>
+<compiler code="xlf">
+<name>xlf</name>
+<value>no</value>
+</compiler>
+<compiler code="zzz_other">
+<name>Other</name>
+<value></value>
+</compiler>
+</compilers>
+</user>
+</users>
Index: /trunk/data/usernemo.dtd
===================================================================
--- /trunk/data/usernemo.dtd	(revision 30)
+++ /trunk/data/usernemo.dtd	(revision 31)
@@ -4,12 +4,12 @@
 
 source :
-/usr/home/fplod/incas/bibnemo/src/bibnemomaf/data/usernemo.dtd sur aedon.locean-ipsl.upmc.fr
+/usr/home/fplod/incas/bibnemo/src/bibnemomaf/data/user.dtd sur aedon.locean-ipsl.upmc.fr
 
 update :
 fplod 2007-04-24T14:20:44Z aedon.locean-ipsl.upmc.fr (Darwin)
 -->
-<!ELEMENT usersnemo (date,usernemo+)>
+<!ELEMENT users (date,user+)>
 <!ELEMENT date (#PCDATA)>
-<!ELEMENT usernemo (userid,personname,email,components,platforms,processors,compilers)>
+<!ELEMENT user (userid,personname,email,components,platforms,processors,compilers)>
 <!ELEMENT userid (#PCDATA)>
 <!ELEMENT personname (surname,firstname,othername)>
Index: /trunk/data/usernemo.xml
===================================================================
--- /trunk/data/usernemo.xml	(revision 30)
+++ /trunk/data/usernemo.xml	(revision 31)
@@ -1,12 +1,12 @@
 <?xml version="1.0" encoding="iso-8859-1"?>
-<!DOCTYPE usersnemo SYSTEM "usernemo.dtd">
+<!DOCTYPE users SYSTEM "user.dtd">
 <!--
 module :
-base des user nemo
-
-source :
-data/usernemo.xml sur aedon.locean-ipsl.upmc.fr
+base des users nemo
 
 update :
+$Id$
+fplod 2007-11-15T13:31:48Z aedon.locean-ipsl.upmc.fr (Darwin)
+remove "nemo"
 fplod 2007-05-09T15:05:12Z aedon.locean-ipsl.upmc.fr (Darwin)
 role='mi'
@@ -14,7 +14,7 @@
 creation
 -->
-<usersnemo>
+<users>
 <date>2007-05-09T15:05:12Z</date>
-<usernemo>
+<user>
 <userid>template</userid>
 <personname>
@@ -113,6 +113,6 @@
 </compiler>
 </compilers>
-</usernemo>
-<usernemo>
+</user>
+<user>
 <userid>A1</userid>
 <personname>
@@ -211,6 +211,6 @@
 </compiler>
 </compilers>
-</usernemo>
-<usernemo>
+</user>
+<user>
 <userid>MASSON_s</userid> <!--++tp-->
 <personname>
@@ -310,4 +310,4 @@
 </compiler>
 </compilers>
-</usernemo>
-</usersnemo>
+</user>
+</users>
Index: /trunk/form_db.xsl
===================================================================
--- /trunk/form_db.xsl	(revision 30)
+++ /trunk/form_db.xsl	(revision 31)
@@ -36,5 +36,5 @@
 <xsl:template name="form_db">
 <!-- ++ template ou existant visu ou modif -->
- <xsl:param name="usernemo"/>
+ <xsl:param name="user"/>
  <xsl:param name="author_id"/>
  <xsl:param name="visu_modif"/>
@@ -85,21 +85,21 @@
 
   <xsl:call-template name="personal">
-   <xsl:with-param name="usernemo" select="$usernemo"/>
+   <xsl:with-param name="user" select="$user"/>
    <xsl:with-param name="visu_modif" select="'modif'"/>
   </xsl:call-template>
   <xsl:call-template name="components">
-   <xsl:with-param name="usernemo" select="$usernemo"/>
+   <xsl:with-param name="user" select="$user"/>
    <xsl:with-param name="visu_modif" select="'modif'"/>
   </xsl:call-template>
   <xsl:call-template name="platforms">
-   <xsl:with-param name="usernemo" select="$usernemo"/>
+   <xsl:with-param name="user" select="$user"/>
    <xsl:with-param name="visu_modif" select="'modif'"/>
   </xsl:call-template>
   <xsl:call-template name="processors">
-   <xsl:with-param name="usernemo" select="$usernemo"/>
+   <xsl:with-param name="user" select="$user"/>
    <xsl:with-param name="visu_modif" select="'modif'"/>
   </xsl:call-template>
   <xsl:call-template name="compilers">
-   <xsl:with-param name="usernemo" select="$usernemo"/>
+   <xsl:with-param name="user" select="$user"/>
    <xsl:with-param name="visu_modif" select="'modif'"/>
   </xsl:call-template>
Index: /trunk/install.sh
===================================================================
--- /trunk/install.sh	(revision 30)
+++ /trunk/install.sh	(revision 31)
@@ -4,8 +4,8 @@
 # publication (rsync) of dirwww content on dirpublish given in argument
 #
-# If the host of publication is cerbere.locean-ipsl.upmc.fr, update_web is
-# launched.
+# If the host of publication is cerbere.locean-ipsl.upmc.fr, a specific update
+# is launched.
 #
-# update
+# update :
 # $Id$
 # fplod 2007-09-28T09:30:43Z aedon.locean-ipsl.upmc.fr (Darwin)
@@ -65,10 +65,11 @@
  rsync -av -e ssh ${dirwww}/ ${dirpublish}
  # detect if in dirpublish following this pattern [USER@]HOST:SRC, HOST
- # is cerbere.locean-ipsl.upmc.fr. If so, update_web is launched
+ # is cerbere.locean-ipsl.upmc.fr. If so, a specific update is launched
  userhost=${dirpublish%%:*}
  host=${userhost##*@}
+ user=${userhost%%@*}
  if [ "${host}" = "cerbere.locean-ipsl.upmc.fr" ]
  then
-  ssh ${userhost} /usr/local_linux/bin/update_web
+    wget -q "http://www.lodyc.jussieu.fr/info_reseau/persoweb/?fastupdate=1&user=${user}" -O /dev/null
  fi
  ;;
Index: /trunk/makefile
===================================================================
--- /trunk/makefile	(revision 30)
+++ /trunk/makefile	(revision 31)
@@ -24,5 +24,5 @@
 
 PRODUIT2 = \
-usernemo
+user
 
 MACHINE_REF = \
@@ -103,12 +103,24 @@
 	@echo "$ make before"
 	@echo ""
-	@echo "identify bibliography databank; for example :"
+	@echo "Identify bibliography databank "
+	@echo ""
+	@echo "for example for superbib demo1:"
+	@echo "$ ln -sf data/bibdemo1.xml bibrefnemo.xml"
+	@echo ""
+	@echo "for example for NEMO Survey :"
 	@echo "$ ln -sf data/biball.xml bibrefnemo.xml"
+	@echo ""
 	@echo "check for duplicate DOI; for example :"
 	@echo "$ ./twindoi.sh -i bibrefnemo.xml -t xml"
 	@echo ""
-	@echo "identify usernemo databank; for example :"
-	@echo "$ ln -sf data/usernemo.xml usernemo.xml"
-	@echo "$ ln -sf data/usernemo.dtd usernemo.dtd"
+	@echo "Identify user databank; for example :"
+	@echo ""
+	@echo "for example for superbib demo1:"
+	@echo "$ ln -sf data/userdemo1.xml user.xml"
+	@echo "$ ln -sf data/usernemo.dtd user.dtd"
+	@echo ""
+	@echo "for example for NEMO Survey :"
+	@echo "$ ln -sf data/usernemo.xml user.xml"
+	@echo "$ ln -sf data/usernemo.dtd user.dtd"
 	@echo ""
 	@echo "Following commands are available to build outputs :"
@@ -464,5 +476,5 @@
 
 $(DIRTMP)/template_db.xml : \
-$(DIRSRC)/usernemo.xml \
+$(DIRSRC)/user.xml \
 $(DIRSRC)/template_db.xsl
 	@xsltproc \
@@ -470,5 +482,5 @@
 	--output $@ \
 	$(DIRSRC)/template_db.xsl \
-	$(DIRSRC)/usernemo.xml
+	$(DIRSRC)/user.xml
 
 $(DIRSRC)/$(PRODUIT)01_xml.xsl : \
@@ -521,5 +533,5 @@
 	@echo "juste pour info dependances de bibnemomain_html.xsl"
 
-$(DIRSRC)/usernemo_html.xsl : \
+$(DIRSRC)/user_html.xsl : \
 $(DIRTMP)/titlepage.$(PRODUIT).xsl \
 $(DIRSRC)/form_html.xsl
Index: /trunk/personal_db.xsl
===================================================================
--- /trunk/personal_db.xsl	(revision 30)
+++ /trunk/personal_db.xsl	(revision 31)
@@ -18,5 +18,5 @@
 
 <xsl:template name="personal">
- <xsl:param name="usernemo"/>
+ <xsl:param name="user"/>
  <xsl:param name="visu_modif"/> <!-- ++ readonly -->
   <xsl:text>&#xA;</xsl:text>
@@ -35,5 +35,5 @@
       <xsl:attribute name="tabindex">1</xsl:attribute> 
       <xsl:attribute name="type">text</xsl:attribute>
-      <xsl:attribute name="value"><xsl:value-of select="$usernemo/personname/surname"/></xsl:attribute> 
+      <xsl:attribute name="value"><xsl:value-of select="$user/personname/surname"/></xsl:attribute> 
     </xsl:element>
    </xsl:element>
@@ -46,5 +46,5 @@
      <xsl:attribute name="tabindex">2</xsl:attribute> 
      <xsl:attribute name="type">text</xsl:attribute>
-     <xsl:attribute name="value"><xsl:value-of select="$usernemo/personname/firstname"/></xsl:attribute> 
+     <xsl:attribute name="value"><xsl:value-of select="$user/personname/firstname"/></xsl:attribute> 
     </xsl:element>
    </xsl:element>
@@ -69,5 +69,5 @@
      <xsl:attribute name="type">text</xsl:attribute>
      <xsl:attribute name="value"></xsl:attribute> 
-     <xsl:attribute name="value"><xsl:value-of select="$usernemo/email"/></xsl:attribute> 
+     <xsl:attribute name="value"><xsl:value-of select="$user/email"/></xsl:attribute> 
     </xsl:element>
    </xsl:element>
Index: /trunk/platforms_db.xsl
===================================================================
--- /trunk/platforms_db.xsl	(revision 30)
+++ /trunk/platforms_db.xsl	(revision 31)
@@ -22,5 +22,5 @@
 
 <xsl:template name="platforms">
- <xsl:param name="usernemo"/>
+ <xsl:param name="user"/>
  <xsl:param name="visu_modif"/>
 
@@ -36,5 +36,5 @@
     <xsl:element name="label">
    -->
-    <xsl:for-each select="$usernemo/platforms/platform">
+    <xsl:for-each select="$user/platforms/platform">
      <xsl:sort order="ascending" data-type="text" select="@code"/>
      <xsl:text>&#xA;</xsl:text>
Index: /trunk/processors_db.xsl
===================================================================
--- /trunk/processors_db.xsl	(revision 30)
+++ /trunk/processors_db.xsl	(revision 31)
@@ -18,5 +18,5 @@
 
 <xsl:template name="processors">
- <xsl:param name="usernemo"/>
+ <xsl:param name="user"/>
  <xsl:param name="visu_modif"/> <!-- ++ readonly -->
  <xsl:text>&#xA;</xsl:text>
@@ -32,5 +32,5 @@
      <xsl:attribute name="rows">1</xsl:attribute>
      <xsl:attribute name="cols">8</xsl:attribute>
-     <xsl:value-of select="$usernemo/processors"/>
+     <xsl:value-of select="$user/processors"/>
    </xsl:element>
  </xsl:element>
Index: /trunk/superbibmany02_xml.xsl
===================================================================
--- /trunk/superbibmany02_xml.xsl	(revision 30)
+++ /trunk/superbibmany02_xml.xsl	(revision 31)
@@ -9,5 +9,5 @@
 
 update :
-++ parametrer le nom du fichier "base utilisateur" usernemo.xml
+++ parametrer le nom du fichier "base utilisateur" user.xml
 fplod 2007-10-17T08:06:40Z aedon.locean-ipsl.upmc.fr (Darwin)
 improve sort (diacriticals)
@@ -17,5 +17,5 @@
 correction pour homonymes partiels
 fplod 2007-05-15T15:07:37Z aedon.locean-ipsl.upmc.fr (Darwin)
-modification to see usernemo/userid="template" information if author_id 
+modification to see user/userid="template" information if author_id 
 doesn't exit in users datafile
 fplod 2007-04-16T08:10:06Z aedon.locean-ipsl.upmc.fr (Darwin)
@@ -68,5 +68,5 @@
    The mail sent by filling these forms will be used to update
 <ulink url="../../one/bibnemomain.php">Nemo-Puplications-Papers</ulink>
-and <ulink url="../../one/usernemo.html">Nemo Users</ulink>.
+and <ulink url="../../one/user.html">Nemo Users</ulink>.
 </xsl:element>
 
@@ -75,5 +75,5 @@
 </para>
 <para>
-Last update of the usernemo databank : <xsl:value-of select="document('usernemo.xml')/usersnemo/date"/>
+Last update of the user databank : <xsl:value-of select="document('user.xml')/users/date"/>
 </para>
 
@@ -149,12 +149,12 @@
    The mail sent by filling this form will be used to update
 <ulink url="../../one/bibnemomain.php">Nemo-Puplications-Papers</ulink>
-and <ulink url="../../one/usernemo.html">Nemo Users</ulink>.
+and <ulink url="../../one/user.html">Nemo Users</ulink>.
   </xsl:element>
 
   <xsl:choose>
-   <xsl:when test="document('usernemo.xml')/usersnemo/usernemo[descendant::userid=$author_id]/userid = $author_id">
+   <xsl:when test="document('user.xml')/users/user[descendant::userid=$author_id]/userid = $author_id">
     <xsl:call-template name="form_db">
      <xsl:with-param name="author_id" select="$author_id"/>
-     <xsl:with-param name="usernemo" select="document('usernemo.xml')/usersnemo/usernemo[descendant::userid=$author_id]"/>
+     <xsl:with-param name="user" select="document('user.xml')/users/user[descendant::userid=$author_id]"/>
      <xsl:with-param name="visu_modif" select="'modif'"/>
      <xsl:with-param name="bibmode" select="'yes'"/>
@@ -164,5 +164,5 @@
     <xsl:call-template name="form_db">
      <xsl:with-param name="author_id" select="$author_id"/>
-     <xsl:with-param name="usernemo" select="document('usernemo.xml')/usersnemo/usernemo[descendant::userid='template']"/>
+     <xsl:with-param name="user" select="document('user.xml')/users/user[descendant::userid='template']"/>
      <xsl:with-param name="visu_modif" select="'modif'"/>
      <xsl:with-param name="bibmode" select="'yes'"/>
Index: /trunk/template_db.xsl
===================================================================
--- /trunk/template_db.xsl	(revision 30)
+++ /trunk/template_db.xsl	(revision 31)
@@ -5,8 +5,6 @@
 creation du prototype de formulaire utilisateur
 
-source :
-/usr/home/fplod/incas/bibnemo/src/bibnemomaf/template_db.xsl sur aedon.locean-ipsl.upmc.fr
-
 update :
+$Id$
 creation
 fplod 2007-04-26T09:31:32Z aedon.locean-ipsl.upmc.fr (Darwin)
@@ -27,10 +25,10 @@
 <xsl:include href="form_db.xsl"/>
 
-<xsl:template match="usersnemo">
+<xsl:template match="users">
 
- <xsl:apply-templates select="usernemo[child::userid='template']"/>
+ <xsl:apply-templates select="user[child::userid='template']"/>
 </xsl:template>
 
-<xsl:template match="usernemo[child::userid='template']">
+<xsl:template match="user[child::userid='template']">
 <article id="template_form" lang="en">
  <title>Nemo Survey - Template</title>
@@ -48,6 +46,6 @@
 
  <xsl:comment> 
-  template form from template userid in usernemo.xml.
-Last update of the usernemo databank : <xsl:value-of select="ancestor::usersnemo/child::date"/>
+  template form from template userid in user.xml.
+Last update of the user databank : <xsl:value-of select="ancestor::users/child::date"/>
  </xsl:comment>
  <xsl:text>&#xA;</xsl:text>
@@ -58,5 +56,5 @@
    The mail sent by filling this form will be used to update 
 <ulink url="bibnemomain.php">Nemo-Puplications-Papers</ulink>
-and <ulink url="usernemo.html">Nemo Users</ulink>.
+and <ulink url="user.html">Nemo Users</ulink>.
   </xsl:element>
  </xsl:element>
@@ -82,5 +80,5 @@
   <xsl:call-template name="form_db">
    <xsl:with-param name="author_id" select="userid"/>
-   <xsl:with-param name="usernemo" select="."/>
+   <xsl:with-param name="user" select="."/>
    <xsl:with-param name="visu_modif" select="'modif'"/>
    <xsl:with-param name="bibmode" select="'no'"/>
Index: /trunk/user_db.xml
===================================================================
--- /trunk/user_db.xml	(revision 31)
+++ /trunk/user_db.xml	(revision 31)
@@ -0,0 +1,155 @@
+<?xml version="1.0" encoding="iso-8859-1"?>
+
+<!--
+module :
+creation des élements de formulaire (sans saisie) d'après les info usernemo
+
+source :
+/usr/home/fplod/incas/bibnemo/src/bibnemomaf/userinfo_db.xsl sur aedon.locean-ipsl.upmc.fr
+
+update :
+$Id$
+fplod 2007-06-06T10:20:22Z aedon.locean-ipsl.upmc.fr (Darwin)
+add middle name
+fplod 2007-05-04T10:26:02Z aedon.locean-ipsl.upmc.fr (Darwin)
+hohmogéneisation sur bibnemo pr auteur et par année
+fplod 2007-04-20T15:31:20Z aedon.locean-ipsl.upmc.fr (Darwin)
+creation
+-->
+
+<xsl:stylesheet
+ id="id" version="1.0"
+ xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
+
+<xsl:include href="components_db.xsl"/>
+<xsl:include href="compilers_db.xsl"/>
+<xsl:include href="platforms_db.xsl"/>
+<xsl:include href="processors_db.xsl"/>
+
+<xsl:output
+ method="xml"
+ indent="yes"
+ encoding="ISO-8859-1"
+ omit-xml-declaration="no"
+ doctype-public="-//OASIS//DTD DocBook XML V4.5//EN"
+ doctype-system="http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd"/>
+
+<xsl:template match="usersnemo">
+ <article id="usersnemo" lang="en">
+
+ <title>Nemo Users</title>
+<articleinfo>
+<authorgroup>
+<author><personname><firstname>Sébastien</firstname> <surname>Masson</surname></personname></author>
+<author><personname><firstname>Françoise</firstname> <surname>Pinsard</surname></personname></author>
+<!--++-->
+</authorgroup>
+<keywordset>
+<keyword>NEMO</keyword>
+</keywordset>
+</articleinfo>
+<highlights id="top">
+<para>
+This page intents to provide an exhaustive list of the papers that have used 
+NEMO or OPA and/or results from them. 
+Obvioulsy many papers are missing.
+If you find omissions or mistakes please ask some modification via
+<xsl:element name="ulink">
+ <xsl:attribute name="url">
+  <xsl:value-of select="'./bibnemomain.php'"/>
+ </xsl:attribute>
+ <xsl:text>Nemo Survey main page</xsl:text>
+</xsl:element>.
+</para>
+</highlights>
+<para>
+Yoy can also see <quote>NEMO - Publications - Papers</quote> sorted by
+<xsl:text>authors</xsl:text>
+authors in
+<xsl:element name="ulink">
+ <xsl:attribute name="url">
+  <xsl:value-of select="'./bibnemomaf02.html'"/>
+ </xsl:attribute>
+ <xsl:text>one big document </xsl:text>
+</xsl:element>
+<xsl:text> or in </xsl:text>
+<xsl:element name="ulink">
+ <xsl:attribute name="url">
+  <xsl:value-of select="'../many/bibnemomaf01/index.html'"/>
+ </xsl:attribute>
+ <xsl:text>several </xsl:text>
+</xsl:element> <xsl:text> (one by author)</xsl:text>.
+</para>
+
+<para>
+Last update of the usernemo databank : <xsl:value-of select="./date"/>
+</para>
+
+<sect1 id="intro">
+<title>Introduction</title>
+<para>
+This document provide user's information sorted by user's id (<emphasis>SURNAME_f</emphasis>).
+</para>
+</sect1>
+
+ <xsl:for-each select="usernemo">
+ <xsl:sort order="ascending" data-type="text" select="userid"/>
+  <xsl:if test="userid != 'template'">
+   <xsl:apply-templates select="."/>
+  </xsl:if>
+ </xsl:for-each>
+ </article>
+</xsl:template>
+
+<xsl:template match="usernemo">
+ <xsl:text>&#xA;</xsl:text>
+ <xsl:element name="sect1">
+  <xsl:attribute name="id"><xsl:value-of select="userid"/></xsl:attribute>
+  <xsl:text>&#xA;</xsl:text>
+  <xsl:element name="title">
+   <xsl:value-of select="personname/firstname"/> <xsl:text> </xsl:text> <xsl:value-of select="personname/othername[@role='mi']"/> <xsl:text> </xsl:text> <xsl:value-of select="personname/surname"/>
+   <xsl:element name="ulink">
+    <xsl:attribute name="url"><xsl:text>#top</xsl:text></xsl:attribute>
+    <xsl:element name="inlinemediaobject">
+     <xsl:element name="imageobject">
+      <xsl:element name="imagedata">
+       <xsl:attribute name="fileref">../../images/globalicondl11x10_up.gif</xsl:attribute>
+      </xsl:element>
+     </xsl:element>
+     <xsl:element name="textobject">
+      <xsl:element name="phrase">
+       <xsl:text>top</xsl:text>
+      </xsl:element>
+     </xsl:element>
+    </xsl:element>
+   </xsl:element>
+  </xsl:element>
+  <xsl:text>&#xA;</xsl:text>
+  <xsl:element name="para">
+   <xsl:value-of select="email"/>
+  </xsl:element>
+  <xsl:text>&#xA;</xsl:text>
+  <xsl:element name="para"> <!-- ++ para ou form -->
+   <xsl:call-template name="components">
+    <xsl:with-param name="usernemo" select="."/>
+    <xsl:with-param name="visu_modif" select="'visu'"/>
+   </xsl:call-template>
+   <xsl:call-template name="platforms">
+    <xsl:with-param name="usernemo" select="."/>
+    <xsl:with-param name="visu_modif" select="'visu'"/>
+   </xsl:call-template>
+   <xsl:call-template name="processors">
+    <xsl:with-param name="usernemo" select="."/>
+    <xsl:with-param name="visu_modif" select="'visu'"/>
+   </xsl:call-template>
+   <xsl:call-template name="compilers">
+    <xsl:with-param name="usernemo" select="."/>
+    <xsl:with-param name="visu_modif" select="'visu'"/>
+   </xsl:call-template>
+  <xsl:text>&#xA;</xsl:text>
+  </xsl:element>
+ <xsl:text>&#xA;</xsl:text>
+ </xsl:element>
+</xsl:template>
+
+</xsl:stylesheet>
Index: /trunk/user_db.xsl
===================================================================
--- /trunk/user_db.xsl	(revision 31)
+++ /trunk/user_db.xsl	(revision 31)
@@ -0,0 +1,153 @@
+<?xml version="1.0" encoding="iso-8859-1"?>
+
+<!--
+module :
+creation des élements de formulaire (sans saisie) d'après les info user
+
+
+update :
+$Id$
+fplod 2007-06-06T10:20:22Z aedon.locean-ipsl.upmc.fr (Darwin)
+add middle name
+fplod 2007-05-04T10:26:02Z aedon.locean-ipsl.upmc.fr (Darwin)
+hohmogéneisation sur bibnemo pr auteur et par année
+fplod 2007-04-20T15:31:20Z aedon.locean-ipsl.upmc.fr (Darwin)
+creation
+-->
+
+<xsl:stylesheet
+ id="id" version="1.0"
+ xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
+
+<xsl:include href="components_db.xsl"/>
+<xsl:include href="compilers_db.xsl"/>
+<xsl:include href="platforms_db.xsl"/>
+<xsl:include href="processors_db.xsl"/>
+
+<xsl:output
+ method="xml"
+ indent="yes"
+ encoding="ISO-8859-1"
+ omit-xml-declaration="no"
+ doctype-public="-//OASIS//DTD DocBook XML V4.5//EN"
+ doctype-system="http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd"/>
+
+<xsl:template match="users">
+ <article id="users" lang="en">
+
+ <title>Nemo Users</title>
+<articleinfo>
+<authorgroup>
+<author><personname><firstname>Sébastien</firstname> <surname>Masson</surname></personname></author>
+<author><personname><firstname>Françoise</firstname> <surname>Pinsard</surname></personname></author>
+<!--++-->
+</authorgroup>
+<keywordset>
+<keyword>NEMO</keyword>
+</keywordset>
+</articleinfo>
+<highlights id="top">
+<para>
+This page intents to provide an exhaustive list of the papers that have used 
+NEMO or OPA and/or results from them. 
+Obvioulsy many papers are missing.
+If you find omissions or mistakes please ask some modification via
+<xsl:element name="ulink">
+ <xsl:attribute name="url">
+  <xsl:value-of select="'./bibnemomain.php'"/>
+ </xsl:attribute>
+ <xsl:text>Nemo Survey main page</xsl:text>
+</xsl:element>.
+</para>
+</highlights>
+<para>
+Yoy can also see <quote>NEMO - Publications - Papers</quote> sorted by
+<xsl:text>authors</xsl:text>
+authors in
+<xsl:element name="ulink">
+ <xsl:attribute name="url">
+  <xsl:value-of select="'./bibnemomaf02.html'"/>
+ </xsl:attribute>
+ <xsl:text>one big document </xsl:text>
+</xsl:element>
+<xsl:text> or in </xsl:text>
+<xsl:element name="ulink">
+ <xsl:attribute name="url">
+  <xsl:value-of select="'../many/bibnemomaf01/index.html'"/>
+ </xsl:attribute>
+ <xsl:text>several </xsl:text>
+</xsl:element> <xsl:text> (one by author)</xsl:text>.
+</para>
+
+<para>
+Last update of the user databank : <xsl:value-of select="./date"/>
+</para>
+
+<sect1 id="intro">
+<title>Introduction</title>
+<para>
+This document provide user's information sorted by user's id (<emphasis>SURNAME_f</emphasis>).
+</para>
+</sect1>
+
+ <xsl:for-each select="user">
+ <xsl:sort order="ascending" data-type="text" select="userid"/>
+  <xsl:if test="userid != 'template'">
+   <xsl:apply-templates select="."/>
+  </xsl:if>
+ </xsl:for-each>
+ </article>
+</xsl:template>
+
+<xsl:template match="user">
+ <xsl:text>&#xA;</xsl:text>
+ <xsl:element name="sect1">
+  <xsl:attribute name="id"><xsl:value-of select="userid"/></xsl:attribute>
+  <xsl:text>&#xA;</xsl:text>
+  <xsl:element name="title">
+   <xsl:value-of select="personname/firstname"/> <xsl:text> </xsl:text> <xsl:value-of select="personname/othername[@role='mi']"/> <xsl:text> </xsl:text> <xsl:value-of select="personname/surname"/>
+   <xsl:element name="ulink">
+    <xsl:attribute name="url"><xsl:text>#top</xsl:text></xsl:attribute>
+    <xsl:element name="inlinemediaobject">
+     <xsl:element name="imageobject">
+      <xsl:element name="imagedata">
+       <xsl:attribute name="fileref">../../images/globalicondl11x10_up.gif</xsl:attribute>
+      </xsl:element>
+     </xsl:element>
+     <xsl:element name="textobject">
+      <xsl:element name="phrase">
+       <xsl:text>top</xsl:text>
+      </xsl:element>
+     </xsl:element>
+    </xsl:element>
+   </xsl:element>
+  </xsl:element>
+  <xsl:text>&#xA;</xsl:text>
+  <xsl:element name="para">
+   <xsl:value-of select="email"/>
+  </xsl:element>
+  <xsl:text>&#xA;</xsl:text>
+  <xsl:element name="para"> <!-- ++ para ou form -->
+   <xsl:call-template name="components">
+    <xsl:with-param name="user" select="."/>
+    <xsl:with-param name="visu_modif" select="'visu'"/>
+   </xsl:call-template>
+   <xsl:call-template name="platforms">
+    <xsl:with-param name="user" select="."/>
+    <xsl:with-param name="visu_modif" select="'visu'"/>
+   </xsl:call-template>
+   <xsl:call-template name="processors">
+    <xsl:with-param name="user" select="."/>
+    <xsl:with-param name="visu_modif" select="'visu'"/>
+   </xsl:call-template>
+   <xsl:call-template name="compilers">
+    <xsl:with-param name="user" select="."/>
+    <xsl:with-param name="visu_modif" select="'visu'"/>
+   </xsl:call-template>
+  <xsl:text>&#xA;</xsl:text>
+  </xsl:element>
+ <xsl:text>&#xA;</xsl:text>
+ </xsl:element>
+</xsl:template>
+
+</xsl:stylesheet>
Index: /trunk/user_html.xsl
===================================================================
--- /trunk/user_html.xsl	(revision 31)
+++ /trunk/user_html.xsl	(revision 31)
@@ -0,0 +1,43 @@
+<?xml version='1.0' encoding='ISO-8859-1'?> 
+<!--
+module :
+transformation docbook en plusieurs html avec formulaire
+
+source :
+/usr/home/fplod/incas/bibnemo/src/bibnemomaf/bibnemomain_html.xsl sur aedon.locean-ipsl.upmc.fr
+
+mise à jour :
+fplod 2007-04-18T08:15:46Z aedon.locean-ipsl.upmc.fr (Darwin)
+création
+-->
+<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"> 
+
+<xsl:import href="http://docbook.sourceforge.net/release/xsl/current/xhtml/docbook.xsl"/>
+
+<xsl:output method="xml" 
+encoding="utf-8" 
+indent="yes" 
+omit-xml-declaration="yes"
+doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" 
+doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>
+
+<xsl:include href="titlepage.bibnemomaf.xsl"/>
+<xsl:include href="form_html.xsl"/>
+
+<xsl:template match="*" mode="book.titlepage.mode"/>
+<xsl:param name="generate.toc">
+article nop
+</xsl:param>
+<xsl:param name="css.decoration" select="0"/>
+<xsl:param name="section.autolabel" select="0"/>
+
+<!-- 
+Personalisation de bas de page
+-->
+<xsl:template name="user.footer.content">
+  <xsl:element name="p">
+Last update : <xsl:value-of select="$makedate"/>
+  </xsl:element>
+</xsl:template>
+
+</xsl:stylesheet> 
Index: unk/usernemo.dtd
===================================================================
--- /trunk/usernemo.dtd	(revision 30)
+++ 	(revision )
@@ -1,33 +1,0 @@
-<!--
-module :
-DTD user nemo
-
-source :
-/usr/home/fplod/incas/bibnemo/src/bibnemomaf/data/usernemo.dtd sur aedon.locean-ipsl.upmc.fr
-
-update :
-fplod 2007-04-24T14:20:44Z aedon.locean-ipsl.upmc.fr (Darwin)
--->
-<!ELEMENT usersnemo (date,usernemo+)>
-<!ELEMENT date (#PCDATA)>
-<!ELEMENT usernemo (userid,personname,email,components,platforms,processors,compilers)>
-<!ELEMENT userid (#PCDATA)>
-<!ELEMENT personname (surname,firstname,othername)>
-<!ELEMENT surname (#PCDATA)>
-<!ELEMENT firstname (#PCDATA)>
-<!ELEMENT othername (#PCDATA)>
-<!ATTLIST othername role CDATA #IMPLIED>
-<!ELEMENT email (#PCDATA)>
-<!ELEMENT compilers (compiler+)>
-<!ELEMENT compiler (name,value)>
-<!ATTLIST compiler code CDATA #IMPLIED>
-<!ELEMENT components (components_date,component+)>
-<!ELEMENT components_date (#PCDATA)>
-<!ELEMENT component (name,value)>
-<!ATTLIST component code CDATA #IMPLIED>
-<!ELEMENT name (#PCDATA)>
-<!ELEMENT value (#PCDATA)>
-<!ELEMENT platforms (platform+)>
-<!ELEMENT platform (name,value)>
-<!ATTLIST platform code CDATA #IMPLIED>
-<!ELEMENT processors (#PCDATA)>
Index: unk/usernemo_db.xsl
===================================================================
--- /trunk/usernemo_db.xsl	(revision 30)
+++ 	(revision )
@@ -1,155 +1,0 @@
-<?xml version="1.0" encoding="iso-8859-1"?>
-
-<!--
-module :
-creation des élements de formulaire (sans saisie) d'après les info usernemo
-
-source :
-/usr/home/fplod/incas/bibnemo/src/bibnemomaf/userinfo_db.xsl sur aedon.locean-ipsl.upmc.fr
-
-update :
-$Id$
-fplod 2007-06-06T10:20:22Z aedon.locean-ipsl.upmc.fr (Darwin)
-add middle name
-fplod 2007-05-04T10:26:02Z aedon.locean-ipsl.upmc.fr (Darwin)
-hohmogéneisation sur bibnemo pr auteur et par année
-fplod 2007-04-20T15:31:20Z aedon.locean-ipsl.upmc.fr (Darwin)
-creation
--->
-
-<xsl:stylesheet
- id="id" version="1.0"
- xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
-
-<xsl:include href="components_db.xsl"/>
-<xsl:include href="compilers_db.xsl"/>
-<xsl:include href="platforms_db.xsl"/>
-<xsl:include href="processors_db.xsl"/>
-
-<xsl:output
- method="xml"
- indent="yes"
- encoding="ISO-8859-1"
- omit-xml-declaration="no"
- doctype-public="-//OASIS//DTD DocBook XML V4.5//EN"
- doctype-system="http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd"/>
-
-<xsl:template match="usersnemo">
- <article id="usersnemo" lang="en">
-
- <title>Nemo Users</title>
-<articleinfo>
-<authorgroup>
-<author><personname><firstname>Sébastien</firstname> <surname>Masson</surname></personname></author>
-<author><personname><firstname>Françoise</firstname> <surname>Pinsard</surname></personname></author>
-<!--++-->
-</authorgroup>
-<keywordset>
-<keyword>NEMO</keyword>
-</keywordset>
-</articleinfo>
-<highlights id="top">
-<para>
-This page intents to provide an exhaustive list of the papers that have used 
-NEMO or OPA and/or results from them. 
-Obvioulsy many papers are missing.
-If you find omissions or mistakes please ask some modification via
-<xsl:element name="ulink">
- <xsl:attribute name="url">
-  <xsl:value-of select="'./bibnemomain.php'"/>
- </xsl:attribute>
- <xsl:text>Nemo Survey main page</xsl:text>
-</xsl:element>.
-</para>
-</highlights>
-<para>
-Yoy can also see <quote>NEMO - Publications - Papers</quote> sorted by
-<xsl:text>authors</xsl:text>
-authors in
-<xsl:element name="ulink">
- <xsl:attribute name="url">
-  <xsl:value-of select="'./bibnemomaf02.html'"/>
- </xsl:attribute>
- <xsl:text>one big document </xsl:text>
-</xsl:element>
-<xsl:text> or in </xsl:text>
-<xsl:element name="ulink">
- <xsl:attribute name="url">
-  <xsl:value-of select="'../many/bibnemomaf01/index.html'"/>
- </xsl:attribute>
- <xsl:text>several </xsl:text>
-</xsl:element> <xsl:text> (one by author)</xsl:text>.
-</para>
-
-<para>
-Last update of the usernemo databank : <xsl:value-of select="./date"/>
-</para>
-
-<sect1 id="intro">
-<title>Introduction</title>
-<para>
-This document provide user's information sorted by user's id (<emphasis>SURNAME_f</emphasis>).
-</para>
-</sect1>
-
- <xsl:for-each select="usernemo">
- <xsl:sort order="ascending" data-type="text" select="userid"/>
-  <xsl:if test="userid != 'template'">
-   <xsl:apply-templates select="."/>
-  </xsl:if>
- </xsl:for-each>
- </article>
-</xsl:template>
-
-<xsl:template match="usernemo">
- <xsl:text>&#xA;</xsl:text>
- <xsl:element name="sect1">
-  <xsl:attribute name="id"><xsl:value-of select="userid"/></xsl:attribute>
-  <xsl:text>&#xA;</xsl:text>
-  <xsl:element name="title">
-   <xsl:value-of select="personname/firstname"/> <xsl:text> </xsl:text> <xsl:value-of select="personname/othername[@role='mi']"/> <xsl:text> </xsl:text> <xsl:value-of select="personname/surname"/>
-   <xsl:element name="ulink">
-    <xsl:attribute name="url"><xsl:text>#top</xsl:text></xsl:attribute>
-    <xsl:element name="inlinemediaobject">
-     <xsl:element name="imageobject">
-      <xsl:element name="imagedata">
-       <xsl:attribute name="fileref">../../images/globalicondl11x10_up.gif</xsl:attribute>
-      </xsl:element>
-     </xsl:element>
-     <xsl:element name="textobject">
-      <xsl:element name="phrase">
-       <xsl:text>top</xsl:text>
-      </xsl:element>
-     </xsl:element>
-    </xsl:element>
-   </xsl:element>
-  </xsl:element>
-  <xsl:text>&#xA;</xsl:text>
-  <xsl:element name="para">
-   <xsl:value-of select="email"/>
-  </xsl:element>
-  <xsl:text>&#xA;</xsl:text>
-  <xsl:element name="para"> <!-- ++ para ou form -->
-   <xsl:call-template name="components">
-    <xsl:with-param name="usernemo" select="."/>
-    <xsl:with-param name="visu_modif" select="'visu'"/>
-   </xsl:call-template>
-   <xsl:call-template name="platforms">
-    <xsl:with-param name="usernemo" select="."/>
-    <xsl:with-param name="visu_modif" select="'visu'"/>
-   </xsl:call-template>
-   <xsl:call-template name="processors">
-    <xsl:with-param name="usernemo" select="."/>
-    <xsl:with-param name="visu_modif" select="'visu'"/>
-   </xsl:call-template>
-   <xsl:call-template name="compilers">
-    <xsl:with-param name="usernemo" select="."/>
-    <xsl:with-param name="visu_modif" select="'visu'"/>
-   </xsl:call-template>
-  <xsl:text>&#xA;</xsl:text>
-  </xsl:element>
- <xsl:text>&#xA;</xsl:text>
- </xsl:element>
-</xsl:template>
-
-</xsl:stylesheet>
Index: unk/usernemo_html.xsl
===================================================================
--- /trunk/usernemo_html.xsl	(revision 30)
+++ 	(revision )
@@ -1,43 +1,0 @@
-<?xml version='1.0' encoding='ISO-8859-1'?> 
-<!--
-module :
-transformation docbook en plusieurs html avec formulaire
-
-source :
-/usr/home/fplod/incas/bibnemo/src/bibnemomaf/bibnemomain_html.xsl sur aedon.locean-ipsl.upmc.fr
-
-mise à jour :
-fplod 2007-04-18T08:15:46Z aedon.locean-ipsl.upmc.fr (Darwin)
-création
--->
-<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"> 
-
-<xsl:import href="http://docbook.sourceforge.net/release/xsl/current/xhtml/docbook.xsl"/>
-
-<xsl:output method="xml" 
-encoding="utf-8" 
-indent="yes" 
-omit-xml-declaration="yes"
-doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" 
-doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>
-
-<xsl:include href="titlepage.bibnemomaf.xsl"/>
-<xsl:include href="form_html.xsl"/>
-
-<xsl:template match="*" mode="book.titlepage.mode"/>
-<xsl:param name="generate.toc">
-article nop
-</xsl:param>
-<xsl:param name="css.decoration" select="0"/>
-<xsl:param name="section.autolabel" select="0"/>
-
-<!-- 
-Personalisation de bas de page
--->
-<xsl:template name="user.footer.content">
-  <xsl:element name="p">
-Last update : <xsl:value-of select="$makedate"/>
-  </xsl:element>
-</xsl:template>
-
-</xsl:stylesheet> 

Index: /trunk/mailtousernemo.sh
===================================================================
--- /trunk/mailtousernemo.sh	(revision 30)
+++ /trunk/mailtousernemo.sh	(revision 31)
@@ -2,13 +2,10 @@
 #
 # module :
 # convert email text in xml form folloowing usernemo.dtd
 #
 # see also bibopa.sh
 #
-# original location :
-# /usr/home/fplod/incas/bibnemo/src/bibnemomaf/mailtousernemo.sh sur aedon.locean-ipsl.upmc.fr
-#
 # example :
-# $ ./mailtousernemo.sh -m data/mail2007-04-25T08:58:16Z.txt -x ginette.xml
+# $ ./mailtouser.sh -m data/mail2007-04-25T08:58:16Z.txt -x ginette.xml
 #
 # see also bibopa.sh
@@ -43,8 +40,8 @@
 fi
 #
-# check for usernemo.dtd
-if [ ! -f usernemo.dtd ]
-then
-  echo "eee : usernemo.dtd not found"
+# check for user.dtd
+if [ ! -f user.dtd ]
+then
+  echo "eee : user.dtd not found"
   exit 1
 fi
@@ -81,5 +78,5 @@
 #++ err si exist
 #
-echo "<usernemo>" > ${xmloutput}
+echo "<user>" > ${xmloutput}
 echo "<!-- mailbodyfile : ${mailbodyfile} " >> ${xmloutput}
 cat ${mailbodyfile} >> ${xmloutput}
@@ -116,5 +113,5 @@
 elements=components
 element=component
-#++ récupérer les usersnemo/usernemo[child::userid='template']/components/component/name
+#++ récupérer les users/user[child::userid='template']/components/component/name
 unset jlist
 unset jlist_name
@@ -170,5 +167,5 @@
 element=platform
 elements=platforms
-#++ récupérer les usersnemo/usernemo[child::userid='template']/platforms/platform/name
+#++ récupérer les users/user[child::userid='template']/platforms/platform/name
 unset jlist
 unset jlist_name
@@ -301,16 +298,16 @@
 echo "</${elements}>" >> ${xmloutput}
 #
-echo "</usernemo>" >> ${xmloutput}
+echo "</user>" >> ${xmloutput}
 #
 xmloutputfull=/tmp/${xmloutput} # ++
 echo '<?xml version="1.0" encoding="iso-8859-1"?>' > ${xmloutputfull}
-echo '<!DOCTYPE usersnemo SYSTEM "usernemo.dtd">' >> ${xmloutputfull}
-echo '<usersnemo>' >> ${xmloutputfull}
+echo '<!DOCTYPE users SYSTEM "user.dtd">' >> ${xmloutputfull}
+echo '<users>' >> ${xmloutputfull}
 echo '<date>bidon</date>' >> ${xmloutputfull}
 cat ${xmloutput} >> ${xmloutputfull}
-echo '</usersnemo>' >> ${xmloutputfull}
+echo '</users>' >> ${xmloutputfull}
 #
 # ++ parce que je ne sais pas dire où est la dtd dans la commande xmllint
-cp usernemo.dtd /tmp/
+cp user.dtd /tmp/
 xmllint --noout --valid ${xmloutputfull} 1>> ${log} 2>> ${log}
 status=${?}
@@ -321,6 +318,6 @@
  exit 1
 else
- echo " iii : you can include ${xmloutput} in usernemo.xml" #++ filename path
- echo " iii : modify date in usernemo.xml" #++ filename path
+ echo " iii : you can include ${xmloutput} in user.xml" #++ filename path
+ echo " iii : modify date in user.xml" #++ filename path
 fi
 #
@@ -2,13 +2,10 @@
 #
 # module :
-# convert email text in xml form folloowing usernemo.dtd
+# convert email text in xml form folloowing user.dtd
 #
 # see also bibopa.sh